@@ -17,8 +17,6 @@ fn lint_advisory_db() {
 
     runner
         .arg("lint")
-        .arg("--skip-namecheck")
-        .arg("rustdecimal")
         .arg(git::Repository::default_path())
         .capture_stdout()
         .status()
