@@ -14,11 +14,16 @@ use crate::{
     prelude::*,
 };
 use abscissa_core::{
-    config::Override, error::Context, terminal::ColorChoice, FrameworkError, FrameworkErrorKind,
+    FrameworkError, FrameworkErrorKind, config::Override, error::Context, terminal::ColorChoice,
 };
 use clap::{Parser, ValueEnum};
 use rustsec::platforms::target::{Arch, OS};
-use std::{fmt, path::PathBuf, process::exit};
+use std::{
+    fmt,
+    io::{self, IsTerminal},
+    path::PathBuf,
+    process::exit,
+};
 
 #[cfg(feature = "binary-scanning")]
 use self::binary_scanning::BinCommand;
@@ -108,13 +113,6 @@ pub struct AuditCommand {
     )]
     ignore: Vec<String>,
 
-    /// Ignore the sources of packages in Cargo.toml
-    #[arg(
-        long = "ignore-source",
-        help = "Ignore sources of packages in Cargo.toml, matching advisories regardless of source"
-    )]
-    ignore_source: bool,
-
     /// Skip fetching the advisory database git repository
     #[arg(
         short = 'n',
@@ -153,6 +151,14 @@ pub struct AuditCommand {
     )]
     quiet: bool,
 
+    /// Output format
+    #[arg(
+        long = "format",
+        value_name = "FORMAT",
+        help = "Output format: terminal, json, or sarif"
+    )]
+    output_format: Option<OutputFormat>,
+
     /// Output reports as JSON
     #[arg(long = "json", help = "Output report in JSON format")]
     output_json: bool,
@@ -183,14 +189,17 @@ impl AuditCommand {
     /// Get the color configuration
     pub fn term_colors(&self) -> ColorChoice {
         if let Some(color) = self.color {
-            color.into()
-        } else {
-            match std::env::var("CARGO_TERM_COLOR") {
-                Ok(e) if e == "always" => ColorChoice::Always,
-                Ok(e) if e == "never" => ColorChoice::Never,
-                Ok(e) if e == "auto" => ColorChoice::Auto,
-                _ => ColorChoice::default(),
-            }
+            return color.into();
+        }
+
+        match std::env::var("CARGO_TERM_COLOR") {
+            Ok(e) if e == "always" => ColorChoice::Always,
+            Ok(e) if e == "never" => ColorChoice::Never,
+            Ok(e) if e == "auto" => ColorChoice::Auto,
+            _ => match io::stdout().is_terminal() {
+                true => ColorChoice::Auto,
+                false => ColorChoice::Never,
+            },
         }
     }
 }
@@ -210,7 +219,6 @@ impl Override<AuditConfig> for AuditCommand {
             );
         }
 
-        config.advisories.ignore_source |= self.ignore_source;
         config.database.fetch &= !self.no_fetch;
         config.database.stale |= self.stale;
 
@@ -236,8 +244,11 @@ impl Override<AuditConfig> for AuditCommand {
 
         config.output.quiet |= self.quiet;
 
+        // Handle output format (--json flag takes precedence for backward compatibility)
         if self.output_json {
             config.output.format = OutputFormat::Json;
+        } else if let Some(format) = self.output_format {
+            config.output.format = format;
         }
 
         Ok(config)
@@ -299,23 +310,23 @@ mod tests {
     fn override_default_fetch_option() {
         // Assert the default value for the fetch option is true
         let mut config: AuditConfig = AuditConfig::default();
-        assert_eq!(config.database.fetch, true);
+        assert!(config.database.fetch);
 
         let mut audit_command = AuditCommand::default();
 
         let overridden_config = audit_command.override_config(config.clone()).unwrap();
-        assert_eq!(overridden_config.database.fetch, true);
+        assert!(overridden_config.database.fetch);
 
         // as the CLI flag --no-fetch is false when not provided
         // override_config should not change the fetch option
         // when it is set to false in the config file
         config.database.fetch = false;
         let overridden_config = audit_command.override_config(config.clone()).unwrap();
-        assert_eq!(overridden_config.database.fetch, false);
+        assert!(!overridden_config.database.fetch);
 
         config.database.fetch = true;
         audit_command.no_fetch = true;
         let overridden_config = audit_command.override_config(config.clone()).unwrap();
-        assert_eq!(overridden_config.database.fetch, false);
+        assert!(!overridden_config.database.fetch);
     }
 }
